@@ -132,15 +132,15 @@ def main_terminal():
         config_path = os.path.join(os.path.expanduser('~'), '.codebot', 'config.json')
         if os.path.exists(config_path):
             os.remove(config_path)
-        check_config_terminal(force_config=True)  # Check and create the configuration file
+        check_config(force_config=True)  # Check and create the configuration file
     else:
         print("Checking configuration...")
-        check_config_terminal()  # Check and create the configuration file if not exists
+        check_config()  # Check and create the configuration file if not exists
     
    
             
 
-    subprocess.run(["chainlit", "run", "app_terminal.py" "--port", "10086"])  # Run your application
+    subprocess.run(["chainlit", "run", "app_terminal.py", "--port", "10086"])  # Run your application
 
 
 
